@@ -3,8 +3,8 @@
 /* build batch file */
 /*
 #ifdef APE_BATCH_FILE_VERSION
-Set _MA=1115
-Set _MAV=11.15
+Set _MA=1187
+Set _MAV=1187
 #endif
 */
 
@@ -12,10 +12,10 @@ Set _MAV=11.15
 #define APE_VERSION_MAJOR 11
 
 /* build version number */
-#define APE_VERSION_REVISION 15
-#define APE_VERSION_REVISION_NUMBER 15
+#define APE_VERSION_REVISION 87
+#define APE_VERSION_REVISION_NUMBER 87 // needed because a number like 08 is interpreted as octal
 
 /* library interface version, update this whenever the signature of an exported function changes */
-#define APE_INTERFACE_VERSION 13
+#define APE_INTERFACE_VERSION 14
 
 /* leave this so the end of file doesn't get truncated */
